==> haskell-lens-action-0.2.6-277-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-HzEGT8eHFX5JWjUmxTaG8G
key:                  lens-action-0.2.6-HzEGT8eHFX5JWjUmxTaG8G
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  8fa3e2f84e5fbab01fede7cac9892d60
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-HzEGT8eHFX5JWjUmxTaG8G
depends:
    base-4.17.2.1 comonad-5.0.9-CXWyhUwSQECE7YT3hG1acR
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.3.1-D1RUGLJD0B7IsqWvzdm040 mtl-2.2.2
    profunctors-5.6.3-2bacBjK6BiEGJaAzrhOAPz
    semigroupoids-6.0.1-6Xf2JRawX4iCVpLBienb51 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-action-0.2.6-278-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-action.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-action
version:              0.2.6
visibility:           public
id:                   lens-action-0.2.6-mKwcBOtWzDFiboJRCpbdy
key:                  lens-action-0.2.6-mKwcBOtWzDFiboJRCpbdy
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  899fea9695009016fbf5a5d5ccbc189a
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-action-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-action
hs-libraries:         HSlens-action-0.2.6-mKwcBOtWzDFiboJRCpbdy
depends:
    base-4.17.2.1 comonad-5.0.9-E6HUlGQXFnv7OEEIpGkJ7B
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    lens-5.3.1-1UDi0CjALHfJ5iQ7KsOF6H mtl-2.2.2
    profunctors-5.6.3-54dftqYvfC87HlKhU8lZc
    semigroupoids-6.0.1-Ajxt1MUD1pH7gUEFlchfjE transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
